% Regulation of firing frequency in a computational model of a midbrain
% dopaminergic neuron by Kuznetsova, in J. Comput Neurosci 2010 vol 28, pp
% 389

clear all
dt=0.01;t=0:dt:1000; 
N=t(end)/dt; %time in msec
sign_current=0;

% initial values
Y=[-71.68 -71.69 -71.69 .7455 .7381 .7357 0.0000557 0.0000845 0.0000632 .0020 .0020 .0020 .8738 .8739 .8739 .0047 .0047 .0047 .0189 .0189 .0189 .9313 .9313 .8951 .2308 .2307 .2307]';
%====================parameters
global I_Napmax K_mNa I_Capmax K_mCa gNa R T F Na_out g_LCa E_Ca tau_Ca g_KV g_KLeak g_NaLeak g_CaLeak
global E_K tau_Kv gKA_d gKA_s gKA_p g_SK K_mSK dp dd Lp Ld Ra Gpd g_dp g_pd 
global ds Ls Gsp g_ps g_sp Cm fd fp fs fCa Vhalf_m Vhalf_h Vhalf_q_d Sq_d Vhalf_q_p
global Sq_p Vhalf_q_s Sq_s tau_q Istim
%leak current
g_KLeak=5.5*10^(-6); g_NaLeak=2.375*10^(-6); g_CaLeak=0.0136*10^(-6);  %S/cm^21G
% sodium pump currents 
 I_Napmax=0.0092; % in m A/cm^2 
 K_mNa=10; %mM
% Calcium pump current
 I_Capmax=0.00191; % m A/cm^2 
 K_mCa=0.0005; %mM;
% Fast sodium current
 gNa=550*10^(-6); % S/cm^2
 R=8.314; T=308.15; F=96520; Na_out=145; %mM
% L-type Calcium current
 g_LCa=11.196*10^(-6); % S/cm^2
 E_Ca=120; %mV
% time constant for calcium current
 tau_Ca=18; %msec
% Delayed rectifier current
 g_KV=665*10^(-6); % S/cm^2
 E_K=-90; %mV
% time constant for Delayed rectifier current
 tau_Kv=19; %msec
% Transient outward potassium current
 gKA_d=266*10^(-6); gKA_s=570*10^(-6); gKA_p=285*10^(-6); % S/cm^2
 % SK potassium current
 g_SK=59*10^(-6); %59%in S/cm^2 % 
 K_mSK=0.00019; %mM
% Intercompartmental coupling currents
 dp=3; dd=1.5; Lp=150; Ld=350;%mu m
 Ra=40; % Omega cm
 ds=15; Ls=25; %mu m
 Gsp=(dp^2*ds^2)/(2*Ra*0.0001*(Lp*ds^2+Ls*dp^2));
 Gpd=(dp^2*dd^2)/(2*Ra*0.0001*(Lp*dd^2+Ld*dp^2));
 g_ps=Gsp/(dp*Lp); g_sp=4*Gsp/(ds*Ls); 
 g_dp=Gpd/(dd*Ld); g_pd=2*Gpd/(dp*Lp); 
% ODEs
 Cm=1; %  muF/cm^2
 fd=2; fp=2; fs=2; %factor, no units
 fCa=0.05; %factor, no units
 
Istim=0;Istim=0.1*Istim/(pi*ds*Ls);

options=odeset('RelTol',1e-8,'Stats','on','AbsTol',[1e-7 1e-7 1e-7 1e-7 1e-7 1e-7 1e-10 1e-10 1e-10 1e-8 1e-8 1e-8 1e-8 1e-8 1e-8 1e-8 1e-8 1e-8 1e-8 1e-8 1e-8 1e-8 1e-8 1e-8 1e-8 1e-8 1e-8 1e-8 1e-8 1e-8]);
[t,y]=ode15s(@ODE_dopamine,[0 1000],Y);   

figure(1); hold on
plot(t,y(:,3),'k')
figure(2); hold on
plot(t,y(:,7),'k')


data=[t,y(:,3)];
save vs.dat data -ascii

