% Regulation of firing frequency in a computational model of a midbrain
% dopaminergic neuron by Kuznetsova, in J. Comput Neurosci 2010 vol 28, pp
% 389

clear all

%====================parameters
global I_Napmax K_mNa I_Capmax K_mCa gNa R T F Na_out g_LCa E_Ca tau_Ca g_KV g_KLeak g_NaLeak g_CaLeak
global E_K tau_Kv gKA_d gKA_s gKA_p g_SK K_mSK dp dd Lp Ld Ra Gpd g_dp g_pd 
global ds Ls Gsp g_ps g_sp Cm fd fp fs fCa Istim
%leak current
g_KLeak=5.5*10^(-6); g_NaLeak=2.375*10^(-6); g_CaLeak=0.0136*10^(-6);  %S/cm^21G
% sodium pump currents 
 I_Napmax=0.0092; % in m A/cm^2 
 K_mNa=10; %mM
% Calcium pump current
 I_Capmax=0.00191; % m A/cm^2 
 K_mCa=0.0005; %mM;
% Fast sodium current
 gNa=550*10^(-6); % S/cm^2
 R=8.314; T=308.15; F=96520; Na_out=145; %mM
% L-type Calcium current
 g_LCa=11.196*10^(-6); % S/cm^2
 E_Ca=120; %mV
% time constant for calcium current
 tau_Ca=18; %msec
% Delayed rectifier current
 g_KV=665*10^(-6); % S/cm^2
 E_K=-90; %mV
% time constant for Delayed rectifier current
 tau_Kv=19; %msec
% Transient outward potassium current
 gKA_d=266*10^(-6); gKA_s=570*10^(-6); gKA_p=285*10^(-6); % S/cm^2
 % SK potassium current
 g_SK=59*10^(-6); %59%in S/cm^2 % 
 K_mSK=0.00019; %mM
% Intercompartmental coupling currents
 dp=3; dd=1.5; Lp=150; Ld=350;%mu m
 Ra=40; % Omega cm
 ds=15; Ls=25; %mu m
 Gsp=(dp^2*ds^2)/(2*Ra*0.0001*(Lp*ds^2+Ls*dp^2));
 Gpd=(dp^2*dd^2)/(2*Ra*0.0001*(Lp*dd^2+Ld*dp^2));
 g_ps=Gsp/(dp*Lp); g_sp=4*Gsp/(ds*Ls); 
 g_dp=Gpd/(dd*Ld); g_pd=2*Gpd/(dp*Lp); 
% ODEs
 Cm=1; %  muF/cm^2
 fd=2; fp=2; fs=2; %factor, no units
 fCa=0.05; %factor, no units
 Istim=0;Istim=0.1*Istim/(pi*ds*Ls);

%---interface

prompt = 'Type a value in microS if you want a gNa value different than the default 550, otherwise hit return';
result = input(prompt);
gNa = result *10^(-6);
if isempty(result)
    gNa=550*10^(-6);%default value in microsiemens
end

prompt = 'Type a value in pA for Istim if you want to change it from the default 0, otherwise hit return';
   result = input(prompt);
   Istim=0.1*result/(pi*ds*Ls);
   if isempty(result)
    Istim=0;%default value in pA
end
prompt = 'Type a value for fCa if you want to change it from the default 0.05, otherwise hit return';
   result = input(prompt);
   fCa=result;
   if isempty(result)
   fCa=0.05;%default value in pA
end
prompt = 'Type a value in seconds- hit return for default value 2 s ';
endtime = input(prompt);
if isempty(endtime)
    endtime=2;%default value in sec
end
prompt = 'Type R or r  to restart from the end of the last simulation- hit return for default initial conditions';
str = input(prompt,'s');
if isempty(str)
    Y=[-71.68 -71.69 -71.69 .7455 .7381 .7357 0.0000557 0.0000845 0.0000632 .0020 .0020 .0020 .8738 .8739 .8739 .0047 .0047 .0047 .0189 .0189 .0189 .9313 .9313 .8951 .2308 .2307 .2307]';
else
if str=='R' || str=='r'
    if exist('initial.dat', 'file')% File exists.  
       load initial.dat
       Y=initial;
    else % File does not exist.
      display('Warning: file does not exist as you are running this code for the first time. The default initial values will be used instead.');
      Y=[-71.68 -71.69 -71.69 .7455 .7381 .7357 0.0000557 0.0000845 0.0000632 .0020 .0020 .0020 .8738 .8739 .8739 .0047 .0047 .0047 .0189 .0189 .0189 .9313 .9313 .8951 .2308 .2307 .2307]';
    end
else %default initial values
    Y=[-71.68 -71.69 -71.69 .7455 .7381 .7357 0.0000557 0.0000845 0.0000632 .0020 .0020 .0020 .8738 .8739 .8739 .0047 .0047 .0047 .0189 .0189 .0189 .9313 .9313 .8951 .2308 .2307 .2307]';
end
end
%--- calculation
options=odeset('RelTol',1e-8,'Stats','on','AbsTol',[1e-7 1e-7 1e-7 1e-7 1e-7 1e-7 1e-10 1e-10 1e-10 1e-8 1e-8 1e-8 1e-8 1e-8 1e-8 1e-8 1e-8 1e-8 1e-8 1e-8 1e-8 1e-8 1e-8 1e-8 1e-8 1e-8 1e-8 1e-8 1e-8 1e-8]);
[t,y]=ode15s(@ODE_dopamine,[0 endtime*1000],Y); %time is in msec in the code

%---- plotting
figure(1); hold on
plot(t*0.001,y(:,3),'k') 
title('Somatic membrane potential')
xlabel('time(sec) ')
ylabel('voltage (mV)')
figure(2); hold on
plot(t*0.001,y(:,7)*10^6,'k')
title('Distal dendritic Ca2+ concentration')
xlabel('time(sec) ')
ylabel('[Ca](nM)')

%-----recording
data=[t,y]; endvalue=y(end,:)';
save initial.dat endvalue -ascii
