%
%	function NewW=AChLearn(Apre,Apost,W,ACh)
%
% 	Learns N input/output pattern pairs using an ACh-modulated Hebbian learning rule
%
%	Apre: mxN matrix of m neurons encoding N different patterns)
%	Apost: pxN matrix of p neurons encoding N different patterns
% 	W: pxm initial weight (connection) matrix
%	ACh: Set presence of cholinergic modulation. ACh=1 means that cholinergic presynaptic inhibition of
%		glutamatergic synaptic transmission is present. ACh=0 means it is absent.
%
%	Returns NewW: The new weight matrix
%
%	See Also: AChRecall() and AChPlot()
%
% Authors: Michael Hasselmo, Jean-Marc Fellous
% in 'Neuromodulation: Increasing Computational Power', Fellous JM, Canavier C and Hasselmo M, 
%			From Brain to Cognition via Computational Neuroscience (M.A. Arbib, editor), 2014.
%



function NewW=AChLearn(Apre,Apost,W,ACh)
NewW=[];
N=size(Apre,2);
if size(Apost,2) ~=N
	fprintf('*** Error: the number of pre and post patterns should be identical \n')
	return
end

for i=1:N				% iterate on each of the pre-post pairs
	pre=Apre(:,i);
	post=Apost(:,i);
	%Post-synaptic activity is sum of direct postsynaptic
	%input and spread of activity across synapses W.
	p=post+(1-ACh)*W*pre;
	%Perform Hebbian synaptic modification.
	dW=p*pre';
	%Update weight matrix.
	W=W+dW;
end

NewW=W;