%
%	function AChPlot(APre,APost,W,ACue,AOut)
%
% 	Plots the pre and post patterns, and the connection matrix (learning phase)
%	Plots the cue and output matrices (recall phases)
%
%	Apre: mxN matrix of m neurons encoding N different patterns)
%	Apost: pxN matrix of p neurons encoding N different patterns
% 	W: pxm weight (connection) matrix (use AChLearn() to initialize, or make it empty to enter by hand)
%	ACue: mxK matrix of cues to be recalled
%	AOut:	pxK matrix of recalled items
%
%	Returns NewW: The new weight matrix
%
%	See Also: AChRecall() and AChLearn()
%
% Authors: Michael Hasselmo, Jean-Marc Fellous
% in 'Neuromodulation: Increasing Computational Power', Fellous JM, Canavier C and Hasselmo M, 
%			From Brain to Cognition via Computational Neuroscience (M.A. Arbib, editor), 2014.
%



function AChPlot(APre,APost,W,ACue,AOut,ACh)


figure('name','Presynaptic encoding patterns 1 and 2','Numbertitle','off','Position',[200 550 400 80]); axpre=gcf;
hintonw(0.8*APre'); set(gcf,'UserData',APre');
ylabel('Pattern'); xlabel('Input neuron'); grid off;
colormap(gray);
P=get(gcf,'Position');
uicontrol('Style', 'pushbutton', 'String', 'Change','Position', [5 5 50 15],'Callback', @Change);    
    

figure('name','Postsynaptic encoding patterns 1 and 2','Numbertitle','off','Position',[50 50 10 400]); axpost=gcf;
hintonw(0.8*APost); set(gcf,'UserData',APost);
ylabel('Output neuron'); xlabel('Pattern'); grid off;
colormap(gray);    
P=get(gcf,'Position');
uicontrol('Style', 'pushbutton', 'String', 'Change','Position', [5 5 50 15],'Callback', @Change);          

h=figure('name','Weight matrix W','Numbertitle','off','Position',[200 50 400 400]); axW=gcf;
hintonw(0.8*W); set(gcf,'UserData',W);
colormap(gray);
xlabel('Input neuron'); ylabel('Output neuron'); grid off;
uicontrol('Style', 'pushbutton', 'String', 'ReCompute','Position', [5 5 70 15],'Callback', @Recompute);     

G.pre=axpre;
G.post=axpost;
G.w=axW;

figure('name','Presynaptic retrieval pattern 1 cue','Numbertitle','off','Position',[800 550 400 80]); axcue=gcf;
hintonw(0.8*ACue'); set(gcf,'UserData',ACue');
ylabel('Pattern'); xlabel('Input neuron'); grid off;
colormap(gray);
uicontrol('Style', 'pushbutton', 'String', 'Change','Position', [5 5 50 15],'Callback', @Change);    

figure('name','Weight matrix W','Numbertitle','off','Position',[800 50 400 400]); axW2=gcf;
hintonw(0.8*W);set(gcf,'UserData',W);
colormap(gray);
xlabel('Input neuron'); ylabel('Output neuron'); grid off

hout=figure('name','Postsynaptic retrieval output','Numbertitle','off','Position',[1220 50 10 400]); axout=gcf;
hintonw(0.8*AOut); set(gcf,'UserData',AOut);
ylabel('Output neuron'); xlabel('Pattern'); grid off;
colormap(gray);
uicontrol('Style', 'pushbutton', 'String', 'ReCompute','Position', [5 5 70 15],'Callback', @RecomputeOut);     

G.cue=axcue;
G.out=axout;
G.w2=axW2;

hACh=figure('name','ACh Level','Numbertitle','off','Position',[650 100 8 350]); axach=gcf;
sh=uicontrol('Style', 'slider', 'Min',0,'Max',1,'Value',ACh,'String','ACh','Position', [30, 20, 50, 300],'Callback', @ChangeACh);     
title('Ach'); set(gcf,'UserData',ACh);
axis('off')

G.ach=sh;

guidata(hout,G);		% need G in order to recompute
guidata(h,G);    
guidata(hACh,G);
    
end


% Function to flip neurons
function Change(hObject, event, handles)  

	id=round(ginput(1));
	d=get(gcf,'UserData');
	d(id(2),id(1))=1-d(id(2),id(1));
	hintonw(0.8*d);set(gcf,'UserData',d);grid off;

end

% Function Change ACh levels
function ChangeACh(hObject, event, handles)  

	G=guidata(gcbo);
	set(gcf,'UserData',get(G.ach,'value'));

end

% Function to recompute (retrain) the matrix using the current
%	pre and post synaptic patterns
function Recompute(hObject, event, handles)  % Relearn

	G=guidata(gcbo);
	Apre=get(G.pre,'UserData')';
	Apost=get(G.post,'UserData');
	W=get(G.w,'UserData');
	ACh=get(G.ach,'value');
	iniW=zeros(size(W));						% Learns from scratch
	NewW=AChLearn(Apre,Apost,iniW,ACh);
	figure(G.w)
	hintonw(0.8*NewW); set(gcf,'UserData',NewW); grid off;
	
	figure(G.w2)				% updates the recall W matrix
	hintonw(0.8*NewW);set(gcf,'UserData',NewW);grid off;
	figure(G.out)				% update the recalled vector, given the current cue vectors
	RecomputeOut([],[],[]);
end

% Function to retreive memories using the current cues
function RecomputeOut(hObject, event, handles)  % Re-Recall

	G=guidata(gcbo);
	Acue=get(G.cue,'UserData')';
	W=get(G.w2,'UserData');
	ACh=get(G.ach,'value');
	% retrieve
	AOut=AChRecall(Acue,W,ACh);
	% update the plot
	hintonw(0.8*AOut); set(gcf,'UserData',AOut); grid off;

end