%
%	function OutPuts=AChRecall(Inputs,W,ACh)
%
% 	Test the connection matrix W using N Inputs. With partial inputs, this will test the 
%		ability to retrieve the postsynaptic activity associated with particular features of
%		the presynaptic activity pattern used during learning.
%
%	Inputs: mxN matrix of m neurons encoding N different input cues
% 	W: pxm  weight (connection) matrix
%	ACh: Set presence of cholinergic modulation. ACh=1 means that cholinergic presynaptic inhibition of
%		glutamatergic synaptic transmission is present. ACh=0 means it is absent. In Recall mode, ACh
%		is unused.
%
%	Returns OutPuts: pxN outputs corresponding to the inputs
%
%	See Also: AChLearn() and AChPlot()
%
% Authors: Michael Hasselmo, Jean-Marc Fellous
% in 'Neuromodulation: Increasing Computational Power', Fellous JM, Canavier C and Hasselmo M, 
%			From Brain to Cognition via Computational Neuroscience (M.A. Arbib, editor), 2014.
%


function Outs=AChRecall(Inputs,W,ACh)

Outs=[];
N=size(Inputs,1);
if size(W,2) ~=N
	fprintf('*** Error: the number of input neurons should be the same as the number of columns of the connection matrix \n')
	return
end

for i=1:size(Inputs,2)				% iterate on each of the pre-post pairs
	cue=Inputs(:,i);
	
	out=W*cue;
	
	%Apply shunting inhibition
	if sum(cue)>0
		out=out/sum(cue);
	end
	
	%Apply thresholding input-output function.
	out=out>0.9;

	Outs=[Outs out];
end

